@@ -140,6 +140,7 @@ class ErrorCodes(object):
             VerificationMerchantAccountIdIsInvalid = "91728"
             VerificationMerchantAccountIsForbidden = "91743"
             VerificationMerchantAccountIsSuspended = "91742"
+            VerificationMerchantAccountCannotBeSubMerchantAccount = "91755"
 
 
     class Customer(object):
@@ -187,6 +188,11 @@ class ErrorCodes(object):
         InconsistentCountry = "93612"
         PaymentMethodsAreInvalid = "93613"
         PaymentMethodsAreNotAllowed = "93615"
+        MerchantAccountExistsForCurrency = "93616"
+        CurrencyIsRequired = "93617"
+        CurrencyIsInvalid = "93618"
+        NoMerchantAccounts = "93619"
+        MerchantAccountExistsForId = "93620"
 
     class MerchantAccount(object):
         IdFormatIsInvalid = "82603"
@@ -304,6 +310,7 @@ class ErrorCodes(object):
             MerchantAccountIdIsInvalid = "94204"
             MerchantAccountIsSuspended = "94205"
             MerchantAccountIsForbidden = "94206"
+            MerchantAccountCannotBeSubMerchantAccount = "94208"
 
     class PaymentMethod(object):
         CannotForwardPaymentMethodType = "93106"
@@ -423,6 +430,7 @@ class ErrorCodes(object):
     class Transaction(object):
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
+        AmountDoesNotMatchIdealPaymentAmount = "915144"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
@@ -431,6 +439,7 @@ class ErrorCodes(object):
         CannotBeVoided = "91504"
         CannotCancelRelease = "91562"
         CannotCloneCredit = "91543"
+        CannotCloneMarketplaceTransaction = "915137"
         CannotCloneTransactionWithPayPalAccount = "91573"
         CannotCloneTransactionWithVaultCreditCard = "91540"
         CannotCloneUnsuccessfulTransaction = "91542"
@@ -456,13 +465,17 @@ class ErrorCodes(object):
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
         HasAlreadyBeenRefunded = "91512"
+        IdealPaymentNotComplete = "815141"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
+        MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdIsInvalid = "91513"
         MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
         MerchantAccountNameIsInvalid = "91513" # Deprecated
+        OrderIdDoesNotMatchIdealPaymentOrderId = "91503"
+        OrderIdIsRequiredWithIdealPayment = "91502"
         OrderIdIsTooLong = "91501"
         PayPalAuthExpired = "91579"
         PayPalNotEnabled = "91576"
